==> zio-aws-servicecatalog_2.13-5.17.151.2-sources.jar: zio/aws/servicecatalog/model/DisassociatePrincipalFromPortfolioRequest.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.servicecatalog.model.primitives.{
  PrincipalARN,
  Id,
  AcceptLanguage
}
import scala.jdk.CollectionConverters._
final case class DisassociatePrincipalFromPortfolioRequest(
    acceptLanguage: Option[AcceptLanguage] = None,
    portfolioId: Id,
    principalARN: PrincipalARN
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest = {
    import DisassociatePrincipalFromPortfolioRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
      .builder()
      .optionallyWith(
        acceptLanguage.map(value =>
          AcceptLanguage.unwrap(value): java.lang.String
        )
      )(_.acceptLanguage)
      .portfolioId(Id.unwrap(portfolioId): java.lang.String)
      .principalARN(PrincipalARN.unwrap(principalARN): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest.ReadOnly =
    zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
      .wrap(buildAwsValue())
}
object DisassociatePrincipalFromPortfolioRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest =
      zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest(
        acceptLanguage.map(value => value),
        portfolioId,
        principalARN
      )
    def acceptLanguage: Option[AcceptLanguage]
    def portfolioId: Id
    def principalARN: PrincipalARN
    def getAcceptLanguage: ZIO[Any, AwsError, AcceptLanguage] =
      AwsError.unwrapOptionField("acceptLanguage", acceptLanguage)
    def getPortfolioId: ZIO[Any, Nothing, Id] = ZIO.succeed(portfolioId)
    def getPrincipalARN: ZIO[Any, Nothing, PrincipalARN] =
      ZIO.succeed(principalARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
  ) extends zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest.ReadOnly {
    override val acceptLanguage: Option[AcceptLanguage] = scala
      .Option(impl.acceptLanguage())
      .map(value =>
        zio.aws.servicecatalog.model.primitives.AcceptLanguage(value)
      )
    override val portfolioId: Id =
      zio.aws.servicecatalog.model.primitives.Id(impl.portfolioId())
    override val principalARN: PrincipalARN =
      zio.aws.servicecatalog.model.primitives.PrincipalARN(impl.principalARN())
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
  ): zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicecatalog_2.13-5.17.267.6-sources.jar: zio/aws/servicecatalog/model/DisassociatePrincipalFromPortfolioRequest.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.servicecatalog.model.primitives.{
  PrincipalARN,
  Id,
  AcceptLanguage
}
import scala.jdk.CollectionConverters._
final case class DisassociatePrincipalFromPortfolioRequest(
    acceptLanguage: Optional[AcceptLanguage] = Optional.Absent,
    portfolioId: Id,
    principalARN: PrincipalARN
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest = {
    import DisassociatePrincipalFromPortfolioRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
      .builder()
      .optionallyWith(
        acceptLanguage.map(value =>
          AcceptLanguage.unwrap(value): java.lang.String
        )
      )(_.acceptLanguage)
      .portfolioId(Id.unwrap(portfolioId): java.lang.String)
      .principalARN(PrincipalARN.unwrap(principalARN): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest.ReadOnly =
    zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
      .wrap(buildAwsValue())
}
object DisassociatePrincipalFromPortfolioRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest =
      zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest(
        acceptLanguage.map(value => value),
        portfolioId,
        principalARN
      )
    def acceptLanguage: Optional[AcceptLanguage]
    def portfolioId: Id
    def principalARN: PrincipalARN
    def getAcceptLanguage: ZIO[Any, AwsError, AcceptLanguage] =
      AwsError.unwrapOptionField("acceptLanguage", acceptLanguage)
    def getPortfolioId: ZIO[Any, Nothing, Id] = ZIO.succeed(portfolioId)
    def getPrincipalARN: ZIO[Any, Nothing, PrincipalARN] =
      ZIO.succeed(principalARN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
  ) extends zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest.ReadOnly {
    override val acceptLanguage: Optional[AcceptLanguage] =
      zio.aws.core.internal
        .optionalFromNullable(impl.acceptLanguage())
        .map(value =>
          zio.aws.servicecatalog.model.primitives.AcceptLanguage(value)
        )
    override val portfolioId: Id =
      zio.aws.servicecatalog.model.primitives.Id(impl.portfolioId())
    override val principalARN: PrincipalARN =
      zio.aws.servicecatalog.model.primitives.PrincipalARN(impl.principalARN())
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest
  ): zio.aws.servicecatalog.model.DisassociatePrincipalFromPortfolioRequest.ReadOnly =
    new Wrapper(impl)
}
